django\_analyses.serializers.output.definitions package
=======================================================

Submodules
----------

django\_analyses.serializers.output.definitions.file\_output\_definition module
-------------------------------------------------------------------------------

.. automodule:: django_analyses.serializers.output.definitions.file_output_definition
   :members:
   :undoc-members:
   :show-inheritance:

django\_analyses.serializers.output.definitions.output\_definition module
-------------------------------------------------------------------------

.. automodule:: django_analyses.serializers.output.definitions.output_definition
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: django_analyses.serializers.output.definitions
   :members:
   :undoc-members:
   :show-inheritance:
